.. _strafbaar2:


.. raw:: html

    <br>
    <center>

strafbaar
=========

.. raw:: html

    </center>
    <br>


De voorwaarden voor het bestaan van een strafbaar feit zijn:

1) menselijke gedraging/gedraging (commissie: doen of omissie: nalaten)

   het toedienen van gif is de gedraging.

2) die valt binnen de delictsomschrijving

   het delict is moord door het toedienen van gif.

3) is wederrechtelijk

   bij gedwongen zorg is geen sprake van niet wederrechtelijk.

4) is aan schuld te wijten.

   de arts handelt in het zekerheidsbewustzijn dat hij gif toedient en dat
   dat gif dodelijke aandoeningen oplevert. Door het achterwege laten van
   verpleging bij het door het gif opgedane aandoeningen ook daadwerkelijk
   sterft.

De wettelijke schulduitsluitingsgronden zijn:

1) ontoerekeningsvatbaarheid (art. 39 Sr)

   een arts word veronderstelt in zekerheidsbewustzijn te halen, hij dient te weten wat hij doet.

2) psychische overmacht (art. 40 Sr)

   ultimum-remedium, een arts die niet anders kan, moet dat uitleggen aan de rechter dat hij ook niet anders kon.

3) noodweerexces (art. 41 lid 2 Sr)

   noodweer betreft het toedienen van geweld en niet het toedienen van gif.

4) een onbevoegd gegeven ambtelijk bevel (art. 43 lid 2 Sr).

   de burgemeester is niet bevoegt om git toe te laten dienen, enkelt tot het toedienen van onschadelijke medicatie.

De wettelijke rechtvaardigingsgronden zijn:

1) overmacht in de zin van noodtoestand (art. 40 Sr)

   roept snel de noodtoestand uit want de medicijnen die men toedient zijn gif gebleken te zijn.

2) wettelijk voorschrift (art. 42 Sr)

   het voorschrift spreekt over het toedienen van medicatie en medicatie
   word niet schadelijk geacht. Omdat het hier gif, wat dodelijk is, betreft
   kan men zich niet op een wettelijk voorschrift berusten.

3) bevoegd gegeven ambtelijk bevel (art. 43 lid 1 Sr)

   de burgemeester in niet bevoegt om gif toe te laten dienen, enkelt medicijnen die geen schade kunnen.

4) noodweer (art. 41 lid 1 Sr).

   noodweer betreft het toepassen van geweld, niet het toediene van medicatie.
